<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Catch Themes
 * @subpackage Catch Adaptive Pro
 * @since Catch Adaptive Pro 1.0
 */

if ( ! defined( 'CATCHADAPTIVE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Returns the default options for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_get_default_theme_options() {

	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'logo'                                             => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/headers/logo.png',
		'logo_alt_text'                                    => '',
		'logo_disable'                                     => 1,
		'move_title_tagline'                               => 0,

		//Layout
		'theme_layout'                                     => 'right-sidebar',
		'woocommerce_layout'                               => 'right-sidebar',
		'content_layout'                                   => 'columns-layout',
		'single_post_image_layout'                         => 'disabled',
		'hide_archive_meta'                                => 1,
		'hide_archive_content'                             => 0,

		//Header Image
		'enable_featured_header_image'                     => 'entire-site-page-post',
		'featured_image_size'                              => 'slider',

		//Navigation
		'primary_menu_disable'                             => 0,
		'header_toggle_disable'                            => 0,

		//Breadcrumb Options
		'breadcumb_option'                                 => 0,
		'breadcumb_onhomepage'                             => 0,
		'breadcumb_seperator'                              => '&raquo;',

		//Comment Options
		'comment_option'                                   => 'use-wordpress-setting',
		'disable_notes'                                    => 0,
		'disable_website_field'                            => 0,

		//Custom CSS
		'custom_css'                                       => '',

		//Scrollup Options
		'disable_scrollup'                                 => 0,

		//Header Right Sidebar Options
		'disable_header_sidebar'                           => 0,

		//Excerpt Options
		'excerpt_length'                                   => '40',
		'excerpt_more_text'                                => __( 'Read More ...', 'catch-adaptive-pro' ),

		//Homepage / Frontpage Settings
		'front_page_category'                              => '0',

		//Pagination Options
		'pagination_type'                                  => 'default',

		//Promotion Headline Options
		'promotion_headline_option'                        => 'disabled',
		'promotion_headline'                               => __( 'Catch Adaptive Pro is a Premium Responsive WordPress Theme', 'catch-adaptive-pro' ),
		'promotion_subheadline'                            => '',
		'promotion_headline_button'                        => __( 'Buy Now', 'catch-adaptive-pro' ),
		'promotion_headline_url'                           => esc_url( 'https://catchthemes.com' ),
		'promotion_headline_target'                        => 1,

		//Search Options
		'search_text'                                      => __( 'Search...', 'catch-adaptive-pro' ),

		//Single Post Navigation
		'disable_single_post_navigation'                   => 0,

		//Feed Redirect
		'feed_redirect'                                    => '',

		//Font Family Options
		'body_font'                                        => 'open-sans',
		'title_font'                                       => 'open-sans',
		'tagline_font'                                     => 'open-sans',
		'content_title_font'                               => 'open-sans',
		'content_font'                                     => 'open-sans',
		'headings_font'                                    => 'open-sans',
		'reset_typography'                                 => 0,

		//Footer Editor Options
		'footer_left_content'                              => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved. %3$s', '1: Year, 2: Site Title with home URL 3: Privacy Policy Link', 'catch-adaptive-pro' ), '[the-year]', '[site-link]', '[privacy-policy-link]' ),
		'footer_right_content'                             => __( 'Theme', 'catch-adaptive-pro') . ': ' .  '<a target="_blank" href="'. esc_url( $theme_data->get( 'ThemeURI' ) ) .'">'. esc_attr( $theme_data->get( 'Name' ) ) .'</a>',
		'reset_footer_content'                             => 0,

		//Update Notifier
		'update_notifier'                                  => 0,

		//WooCommerce Options
		'disable_product_gallery_zoom'                     => 0,
		'disable_product_gallery_lightbox'                 => 0,
		'disable_product_gallery_slider'                   => 0,

		//Basic Color Options
		'color_scheme'                                     => 'light',
		'background_color'                                 => '#ffffff',
		'text_color'                                       => '#404040',
		'link_color'                                       => '#21759b',
		'link_hover_color'                                 => '#404040',

		//Header Color Options
		'header_textcolor'                                 => '#dddddd',
		'header_background_color'                          => '#000000',
		'site_title_hover_color'                           => '#ffffff',
		'tagline_color'                                    => '#dddddd',

		//Content Color Options
		'content_wrapper_background_color'                 => '#ffffff',
		'content_background_color'                         => '#ffffff',
		'content_title_color'                              => '#404040',
		'content_title_hover_color'                        => '#21759b',
		'content_meta_color'                               => '#21759b',
		'content_meta_hover_color'                         => '#404040',

		//Sidebar Color Options
		'sidebar_background_color'                         => '#ffffff',
		'sidebar_widget_title_background_color'            => '#111111',
		'sidebar_widget_title_color'                       => '#ffffff',
		'sidebar_widget_text_color'                        => '#404040',
		'sidebar_widget_link_color'                        => '#21759b',

		//Pagination Color Options
		'pagination_background_color'                      => '#ffffff',
		'pagination_hover_background_color'                => '#ffffff',
		'pagination_text_color'                            => '#404040',
		'pagination_link_color'                            => '#21759b',
		'pagination_hover_active_color'                    => '#ffffff',
		'numeric_infinite_scroll_background_color'         => '#000000',
		'numeric_infinite_scroll_hover_background_color'   => '#000000',
		'numeric_infinite_scroll_text_color'               => '#dddddd',
		'numeric_infinite_scroll_hover_text_color'         => '#ffffff',

		//Footer Color Options
		'footer_background_color'                          => '#000000',
		'footer_text_color'                                => '#dddddd',
		'footer_link_color'                                => '#dddddd',
		'footer_link_hover_color'                          => '#ffffff',
		'footer_sidebar_area_background_color'             => '#ffffff',
		'footer_widget_background_color'                   => '#ffffff',
		'footer_widget_title_background_color'             => '#111111',
		'footer_widget_title_color'                        => '#ffffff',
		'footer_widget_text_color'                         => '#404040',
		'footer_widget_link_color'                         => '#21759b',
		'footer_widget_link_hover_color'                   => '#404040',

		//Promotion Headline Color Options
		'promotion_headline_background_color'              => '#111111',
		'promotion_headline_text_color'                    => '#dddddd',
		'promotion_headline_link_color'                    => '#21759b',
		'promotion_headline_button_background_color'       => '#21759b',
		'promotion_headline_button_text_color'             => '#ffffff',
		'promotion_headline_button_hover_background_color' => '#165d7d',
		'promotion_headline_button_hover_text_color'       => '#ffffff',
		'promotion_headline_border_color'                  => '#ffffff',

		//Scrollup Color Options
		'scrollup_background_color'                        => '#666666',
		'scrollup_hover_background_color'                  => '#000000',
		'scrollup_text_color'                              => '#eeeeee',
		'scrollup_hover_text_color'                        => '#ffffff',

		//Slider Color Options
		'slider_background_color'                          => '#ffffff',
		'slider_text_color'                                => '#ffffff',
		'slider_link_color'                                => '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'                => '#ffffff',
		'featured_content_title_color'                     => '#ffffff',
		'featured_content_text_color'                      => '#ffffff',
		'featured_content_link_color'                      => '#21759b',

		//Primary Menu Color Options
		'menu_background_color'                            => '#444444',
		'menu_color'                                       => '#dddddd',
		'hover_active_background_color'                    => '#444444',
		'hover_active_text_color'                          => '#ffffff',
		'sub_menu_background_color'                        => '#444444',
		'sub_menu_text_color'                              => '#dddddd',

		//Secondary Menu Color Options
		'secondary_menu_background_color'                  => '#f2f2f2',
		'secondary_menu_color'                             => '#666666',
		'secondary_hover_active_background_color'          => '#f2f2f2',
		'secondary_hover_active_text_color'                => '#21759b',
		'secondary_sub_menu_background_color'              => '#f2f2f2',
		'secondary_sub_menu_text_color'                    => '#666666',

		//Footer Menu Color Options
		'footer_menu_background_color'                     => '#111111',
		'footer_menu_color'                                => '#666666',
		'footer_hover_active_background_color'             => '#111111',
		'footer_hover_active_text_color'                   => '#cccccc',

		//Featured Content Options
		'featured_content_option'                          => 'homepage',
		'featured_content_layout'                          => 'layout-three',
		'featured_content_position'                        => 1,
		'featured_content_slider'                          => 1,
		'featured_content_headline'                        => '',
		'featured_content_subheadline'                     => '',
		'featured_content_type'                            => 'demo-featured-content',
		'featured_content_number'                          => '4',
		'featured_content_enable_title'                    => 1,
		'featured_content_select_category'                 => '0',
		'featured_content_show'                            => 'hide-content',

		'featured_content_background_image'                => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/default-featured-bg.jpg',
		'featured_content_disable_background_image'        => 0,
		'featured_content_background_display_position'     => 'bottom',
		'featured_content_background_repeat'               => 'no-repeat',
		'featured_content_background_attachment'           => 'fixed',

		//Featured Slider Options
		'featured_slider_option'                           => 'disabled',
		'featured_slider_image_loader'                     => 'true',
		'featured_slide_transition_effect'                 => 'fadeout',
		'featured_slide_transition_delay'                  => '4',
		'featured_slide_transition_length'                 => '1',
		'featured_slider_type'                             => 'demo-featured-slider',
		'featured_slide_number'                            => '4',
		'featured_slider_select_category'                  => '0',
		'exclude_slider_post'                              => 0,

		//Social Links
		'social_icon_size'                                 => '20',
		'custom_social_icons'                              => '1',

		//Reset all settings
		'reset_all_settings'                               => 0,
	);

	return apply_filters( 'catchadaptive_default_theme_options', $default_theme_options );
}


/**
 * Returns an array of featured slider image loader options
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_slider_image_loader() {
	$color_scheme_options = array(
		'true'  => __( 'True', 'catch-adaptive-pro' ),
		'wait'  => __( 'Wait', 'catch-adaptive-pro' ),
		'false' => __( 'False', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_color_schemes', $color_scheme_options );
}


/**
 * Returns an array of color schemes registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_color_schemes() {
	$color_scheme_options = array(
		'light' => __( 'Light', 'catch-adaptive-pro' ),
		'dark'  => __( 'Dark', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_color_schemes', $color_scheme_options );
}


/**
 * Returns an array of layout options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_layouts() {
	$layout_options = array(
		'left-sidebar'          => __( 'Primary Sidebar, Content', 'catch-adaptive-pro' ),
		'right-sidebar'         => __( 'Content, Primary Sidebar', 'catch-adaptive-pro' ),
		'no-sidebar'            => __( 'No Sidebar ( Content Width )', 'catch-adaptive-pro' ),
		'no-sidebar-full-width' => __( 'No Sidebar ( Full Width )', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_layouts', $layout_options );
}


/**
 * Returns an array of content layout options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_get_archive_content_layout() {
	$layout_options = array(
		'columns-layout'      => __( 'Columns Layout (Image Top)', 'catch-adaptive-pro' ),
		'excerpt-image-left'  => __( 'Show Excerpt (Image Left)', 'catch-adaptive-pro' ),
		'excerpt-image-right' => __( 'Show Excerpt (Image Right)', 'catch-adaptive-pro' ),
		'excerpt-image-top'   => __( 'Show Excerpt (Image Top)', 'catch-adaptive-pro' ),
		'full-content'        => __( 'Show Full Content (No Featured Image)', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_get_archive_content_layout', $layout_options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_enable_featured_header_image_options() {
	$enable_featured_header_image_options = array(
		'homepage'               => __( 'Homepage / Frontpage', 'catch-adaptive-pro' ),
		'exclude-home'           => __( 'Excluding Homepage', 'catch-adaptive-pro' ),
		'exclude-home-page-post' => __( 'Excluding Homepage, Page/Post Featured Image', 'catch-adaptive-pro' ),
		'entire-site'            => __( 'Entire Site', 'catch-adaptive-pro' ),
		'entire-site-page-post'  => __( 'Entire Site, Page/Post Featured Image', 'catch-adaptive-pro' ),
		'pages-posts'            => __( 'Pages and Posts', 'catch-adaptive-pro' ),
		'disabled'               => __( 'Disabled', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_enable_featured_header_image_options', $enable_featured_header_image_options );
}


/**
 * Returns an array of feature image size
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_image_size_options() {
	$featured_image_size_options = array(
		'full'   => __( 'Full Image', 'catch-adaptive-pro' ),
		'large'  => __( 'Large Image', 'catch-adaptive-pro' ),
		'slider' => __( 'Slider Image', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_image_size_options', $featured_image_size_options );
}


/**
 * Returns an array of content and slider layout options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_slider_content_options() {
	$featured_slider_content_options = array(
		'homepage' 		=> __( 'Homepage / Frontpage', 'catch-adaptive-pro' ),
		'entire-site' 	=> __( 'Entire Site', 'catch-adaptive-pro' ),
		'disabled'		=> __( 'Disabled', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_slider_content_options', $featured_slider_content_options );
}


/**
 * Returns an array of feature content types registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_types() {
	$featured_content_types = array(
		'demo-featured-content'     => __( 'Demo Featured Content', 'catch-adaptive-pro' ),
		'featured-post-content'     => __( 'Featured Post Content', 'catch-adaptive-pro' ),
		'featured-page-content'     => __( 'Featured Page Content', 'catch-adaptive-pro' ),
		'featured-category-content' => __( 'Featured Category Content', 'catch-adaptive-pro' ),
		'featured-image-content'    => __( 'Featured Image Content', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_content_types', $featured_content_types );
}


/**
 * Returns an array of featured content options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_layout_options() {
	$featured_content_layout_option = array(
		'layout-three' => __( '3 columns', 'catch-adaptive-pro' ),
		'layout-four'  => __( '4 columns', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_content_layout_options', $featured_content_layout_option );
}


/**
 * Returns an array of featured content show registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_show() {
	$featured_content_show_option = array(
		'excerpt' 		=> __( 'Show Excerpt', 'catch-adaptive-pro' ),
		'full-content' 	=> __( 'Show Full Content', 'catch-adaptive-pro' ),
		'hide-content' 	=> __( 'Hide Content', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_content_show', $featured_content_show_option );
}


/**
 * Returns an array of feature slider types registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_slider_types() {
	$featured_slider_types = array(
		'demo-featured-slider'     => __( 'Demo Featured Slider', 'catch-adaptive-pro' ),
		'featured-post-slider'     => __( 'Featured Post Slider', 'catch-adaptive-pro' ),
		'featured-page-slider'     => __( 'Featured Page Slider', 'catch-adaptive-pro' ),
		'featured-category-slider' => __( 'Featured Category Slider', 'catch-adaptive-pro' ),
		'featured-image-slider'    => __( 'Featured Image Slider', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_slider_types', $featured_slider_types );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_slide_transition_effects() {
	$featured_slide_transition_effects = array(
		'fade' 		=> __( 'Fade', 'catch-adaptive-pro' ),
		'fadeout' 	=> __( 'Fade Out', 'catch-adaptive-pro' ),
		'none' 		=> __( 'None', 'catch-adaptive-pro' ),
		'scrollHorz'=> __( 'Scroll Horizontal', 'catch-adaptive-pro' ),
		'scrollVert'=> __( 'Scroll Vertical', 'catch-adaptive-pro' ),
		'flipHorz'	=> __( 'Flip Horizontal', 'catch-adaptive-pro' ),
		'flipVert'	=> __( 'Flip Vertical', 'catch-adaptive-pro' ),
		'tileSlide'	=> __( 'Tile Slide', 'catch-adaptive-pro' ),
		'tileBlind'	=> __( 'Tile Blind', 'catch-adaptive-pro' ),
		'shuffle'	=> __( 'Shuffle', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_featured_slide_transition_effects', $featured_slide_transition_effects );
}


/**
 * Returns an array of color schemes registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_get_pagination_types() {
	$pagination_types = array(
		'default'                => __( 'Default(Older Posts/Newer Posts)', 'catch-adaptive-pro' ),
		'numeric'                => __( 'Numeric', 'catch-adaptive-pro' ),
		'infinite-scroll-click'  => __( 'Infinite Scroll (Click)', 'catch-adaptive-pro' ),
		'infinite-scroll-scroll' => __( 'Infinite Scroll (Scroll)', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_get_pagination_types', $pagination_types );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_single_post_image_layout_options() {
	$single_post_image_layout_options = array(
		'featured'  => __( 'Featured', 'catch-adaptive-pro' ),
		'full-size' => __( 'Full Size', 'catch-adaptive-pro' ),
		'disabled'  => __( 'Disabled', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_single_post_image_layout_options', $single_post_image_layout_options );
}


/**
 * Returns an array of comment options for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_comment_options() {
	$comment_options = array(
		'use-wordpress-setting' => __( 'Use WordPress Setting', 'catch-adaptive-pro' ),
		'disable-in-pages'      => __( 'Disable in Pages', 'catch-adaptive-pro' ),
		'disable-completely'    => __( 'Disable Completely', 'catch-adaptive-pro' ),
	);

	return apply_filters( 'catchadaptive_comment_options', $comment_options );
}


/**
 * Returns an array of avaliable fonts registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'rye'         => array(
			'value' => 'rye',
			'label' => '"Rye", cursive',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'catchadaptive_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Catch Adaptive 1.0
*/
function catchadaptive_get_social_icons_list() {
	$catchadaptive_social_icons_list = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'catch-adaptive-pro' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'catch-adaptive-pro' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus-alt',
			'label' 			=> esc_html__( 'Googleplus', 'catch-adaptive-pro' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'catch-adaptive-pro' )
			),
		'feed_link'			=> array(
			'genericon_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'catch-adaptive-pro' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'catch-adaptive-pro' )
			),
		'github_link'		=> array(
			'genericon_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'catch-adaptive-pro' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'catch-adaptive-pro' )
			),
		'pinterest_link'	=> array(
			'genericon_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'catch-adaptive-pro' )
			),
		'flickr_link'		=> array(
			'genericon_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'catch-adaptive-pro' )
			),
		'vimeo_link'		=> array(
			'genericon_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'catch-adaptive-pro' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'catch-adaptive-pro' )
			),
		'tumblr_link'		=> array(
			'genericon_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'catch-adaptive-pro' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'catch-adaptive-pro' )
			),
		'polldaddy_link'	=> array(
			'genericon_class' 	=> 'polldaddy',
			'label' 			=> esc_html__( 'PollDaddy', 'catch-adaptive-pro' )
			),
		'codepen_link'		=> array(
			'genericon_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'catch-adaptive-pro' )
			),
		'path_link'			=> array(
			'genericon_class' 	=> 'path',
			'label' 			=> esc_html__( 'Path', 'catch-adaptive-pro' )
			),
		'dribbble_link'		=> array(
			'genericon_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'catch-adaptive-pro' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'catch-adaptive-pro' )
			),
		'digg_link'			=> array(
			'genericon_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'catch-adaptive-pro' )
			),
		'reddit_link'		=> array(
			'genericon_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'catch-adaptive-pro' )
			),
		'stumbleupon_link'	=> array(
			'genericon_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'catch-adaptive-pro' )
			),
		'pocket_link'		=> array(
			'genericon_class' 	=> 'pocket',
			'label' 			=> esc_html__( 'Pocket', 'catch-adaptive-pro' ),
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'catch-adaptive-pro' ),
			),
		'spotify_link'		=> array(
			'genericon_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'catch-adaptive-pro' ),
			),
		'foursquare_link'	=> array(
			'genericon_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'catch-adaptive-pro' ),
			),
		'twitch_link'		=> array(
			'genericon_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'catch-adaptive-pro' ),
			),
		'website_link'		=> array(
			'genericon_class' 	=> 'website',
			'label' 			=> esc_html__( 'Website', 'catch-adaptive-pro' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'catch-adaptive-pro' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'catch-adaptive-pro' ),
			),
		'cart_link'			=> array(
			'genericon_class' 	=> 'cart',
			'label' 			=> esc_html__( 'Cart', 'catch-adaptive-pro' ),
			),
		'cloud_link'		=> array(
			'genericon_class' 	=> 'cloud',
			'label' 			=> esc_html__( 'Cloud', 'catch-adaptive-pro' ),
			),
		'link_link'		=> array(
			'genericon_class' 	=> 'link',
			'label' 			=> esc_html__( 'Link', 'catch-adaptive-pro' ),
			),
	);

	return apply_filters( 'catchadaptive_social_icons_list', $catchadaptive_social_icons_list );
}


/**
 * Returns list of basic color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_basic_color_options() {
	$options =	array(
					'text_color' 		=> __( 'Text Color', 'catch-adaptive-pro' ),
					'link_color' 		=> __( 'Link Color', 'catch-adaptive-pro' ),
					'link_hover_color'	=> __( 'Link Hover Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_basic_color_options', $options );
}


/**
 * Returns list of header color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_header_color_options() {
	$options =	array(
					'header_background_color' 	=> __( 'Header Background color', 'catch-adaptive-pro' ),
					'site_title_hover_color' 	=> __( 'Site Title Hover Color', 'catch-adaptive-pro' ),
					'tagline_color' 			=> __( 'Tagline Color', 'catch-adaptive-pro' )
				);

	return apply_filters( 'catchadaptive_get_header_color_options', $options );
}


/**
 * Returns list of content color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_content_color_options() {
	$options =	array(
					'content_wrapper_background_color' 	=> __( 'Wrapper Background Color', 'catch-adaptive-pro' ),
					'content_background_color'			=> __( 'Background Color', 'catch-adaptive-pro' ),
					'content_title_color' 				=> __( 'Title Color', 'catch-adaptive-pro' ),
					'content_title_hover_color' 		=> __( 'Title Hover Color', 'catch-adaptive-pro' ),
					'content_meta_color' 				=> __( 'Meta Color', 'catch-adaptive-pro' ),
					'content_meta_hover_color' 			=> __( 'Meta Hover Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_content_color_options', $options );
}


/**
 * Returns list of sidebar color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_sidebar_color_options() {
	$options = array(
					'sidebar_background_color' 				=> __( 'Background Color', 'catch-adaptive-pro' ),
					'sidebar_widget_title_background_color'	=> __( 'Widget Title Background Color', 'catch-adaptive-pro' ),
					'sidebar_widget_title_color' 			=> __( 'Widget Title Color', 'catch-adaptive-pro' ),
					'sidebar_widget_text_color' 			=> __( 'Widget Text Color', 'catch-adaptive-pro' ),
					'sidebar_widget_link_color' 			=> __( 'Widget Link Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_sidebar_color_options', $options );
}


/**
 * Returns list of pagination color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_pagination_color_options() {
	$options =  array(
					'pagination_background_color' 					=> __( 'Background Color', 'catch-adaptive-pro' ),
					'pagination_hover_background_color' 			=> __( 'Hover Background Color', 'catch-adaptive-pro' ),
					'pagination_text_color' 						=> __( 'Text Color', 'catch-adaptive-pro' ),
					'pagination_link_color' 						=> __( 'Link Color', 'catch-adaptive-pro' ),
					'pagination_hover_active_color' 				=> __( 'Hover/Active Color', 'catch-adaptive-pro' ),
					'numeric_infinite_scroll_background_color' 		=> __( 'Numeric/Infinite Scroll Background Color', 'catch-adaptive-pro' ),
					'numeric_infinite_scroll_hover_background_color'=> __( 'Numeric/Infinite Scroll Hover Background Color', 'catch-adaptive-pro' ),
					'numeric_infinite_scroll_text_color'			=> __( 'Numeric/Infinite Scroll Text Color', 'catch-adaptive-pro' ),
					'numeric_infinite_scroll_hover_text_color'		=> __( 'Numeric/Infinite Scroll Hover Text Color', 'catch-adaptive-pro' ),
				);
	return apply_filters( 'catchadaptive_get_pagination_color_options', $options );
}


/**
 * Returns list of footer color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_footer_color_options() {
	$options =	array(
					'footer_background_color' 				=> __( 'Background Color', 'catch-adaptive-pro' ),
					'footer_text_color' 					=> __( 'Text Color', 'catch-adaptive-pro' ),
					'footer_link_color' 					=> __( 'Link Color', 'catch-adaptive-pro' ),
					'footer_link_hover_color' 				=> __( 'Link Hover Color', 'catch-adaptive-pro' ),
					'footer_sidebar_area_background_color' 	=> __( 'Sidebar Area Background Color', 'catch-adaptive-pro' ),
					'footer_widget_background_color' 		=> __( 'Widget Background Color', 'catch-adaptive-pro' ),
					'footer_widget_title_background_color'	=> __( 'Widget Title Background Color', 'catch-adaptive-pro' ),
					'footer_widget_title_color'				=> __( 'Widget Title Color', 'catch-adaptive-pro' ),
					'footer_widget_text_color'				=> __( 'Widget Text Color', 'catch-adaptive-pro' ),
					'footer_widget_link_color'				=> __( 'Widget Link Color', 'catch-adaptive-pro' ),
					'footer_widget_link_hover_color'		=> __( 'Widget Link Hover Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_footer_color_options', $options );
}


/**
 * Returns list of promotion headline color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_promotion_headline_color_options() {
	$options =	array(
					'promotion_headline_background_color'				=> __( 'Background Color', 'catch-adaptive-pro' ),
					'promotion_headline_text_color'						=> __( 'Text Color', 'catch-adaptive-pro' ),
					'promotion_headline_link_color'						=> __( 'Link Color', 'catch-adaptive-pro' ),
					'promotion_headline_button_background_color'		=> __( 'Button Background Color', 'catch-adaptive-pro' ),
					'promotion_headline_button_text_color'				=> __( 'Button Text Color', 'catch-adaptive-pro' ),
					'promotion_headline_button_hover_background_color'	=> __( 'Button Hover Background Color', 'catch-adaptive-pro' ),
					'promotion_headline_button_hover_text_color'		=> __( 'Button Hover Text Color', 'catch-adaptive-pro' ),
					'promotion_headline_border_color'					=> __( 'Button Headline Border Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_promotion_headline_color_options', $options );
}


/**
 * Returns list of scrollup color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_scrollup_color_options() {
	$options =	array(
					'scrollup_background_color'			=> __( 'Background Color', 'catch-adaptive-pro' ),
					'scrollup_hover_background_color'	=> __( 'Hover Background Color', 'catch-adaptive-pro' ),
					'scrollup_text_color'				=> __( 'Text Color', 'catch-adaptive-pro' ),
					'scrollup_hover_text_color'			=> __( 'Hover Text Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_scrollup_color_options', $options );
}


/**
 * Returns list of slider color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_slider_color_options() {
	$options =	array(
					'slider_background_color'	=> __( 'Background Color', 'catch-adaptive-pro' ),
					'slider_text_color'			=> __( 'Text Color', 'catch-adaptive-pro' ),
					'slider_link_color'			=> __( 'Link Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_slider_color_options', $options );
}


/**
 * Returns list of featured_content color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_featured_content_color_options() {
	$options =	array(
					'featured_content_background_color'	=> __( 'Background Color', 'catch-adaptive-pro' ),
					'featured_content_title_color'		=> __( 'Title Color', 'catch-adaptive-pro' ),
					'featured_content_text_color'		=> __( 'Text Color', 'catch-adaptive-pro' ),
					'featured_content_link_color'		=> __( 'Link Color', 'catch-adaptive-pro' ),
				);

	return apply_filters( 'catchadaptive_get_featured_content_color_options', $options );
}


/**
 * Returns list of menu color options currently supported
 *
 * @since Catch Adaptive Pro 1.0
*/
function catchadaptive_get_menu_color_options() {
	$options =	array(
					'menu_background_color'			=> __( 'Menu Background color', 'catch-adaptive-pro' ),
					'menu_color'					=> __( 'Menu Color', 'catch-adaptive-pro' ),
					'hover_active_background_color'	=> __( 'Hover Active Background Color', 'catch-adaptive-pro' ),
					'hover_active_text_color'		=> __( 'Hover Active Text Color', 'catch-adaptive-pro' ),
					'sub_menu_background_color'		=> __( 'Sub Menu Background Color', 'catch-adaptive-pro' ),
					'sub_menu_text_color'			=> __( 'Sub Menu Text Color', 'catch-adaptive-pro' ),
				);
	return apply_filters( 'catchadaptive_get_menu_color_options', $options );
}

/**
 * Returns an array of metabox layout options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_metabox_layouts() {
	$layout_options = array(
		'default' 	=> array(
			'id' 	=> 'catchadaptive-layout-option',
			'value' => 'default',
			'label' => __( 'Default', 'catch-adaptive-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'catchadaptive-layout-option',
			'value' => 'left-sidebar',
			'label' => __( 'Primary Sidebar, Content', 'catch-adaptive-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'catchadaptive-layout-option',
			'value' => 'right-sidebar',
			'label' => __( 'Content, Primary Sidebar', 'catch-adaptive-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'catchadaptive-layout-option',
			'value' => 'no-sidebar',
			'label' => __( 'No Sidebar ( Content Width )', 'catch-adaptive-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'catchadaptive-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => __( 'No Sidebar ( Full Width )', 'catch-adaptive-pro' ),
		),
	);
	return apply_filters( 'catchadaptive_layouts', $layout_options );
}

/**
 * Returns an array of metabox header featured image options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_metabox_header_featured_image_options() {
	$header_featured_image_options = array(
		'default' => array(
			'id'		=> 'catchadaptive-header-image',
			'value' 	=> 'default',
			'label' 	=> __( 'Default', 'catch-adaptive-pro' ),
		),
		'enable' => array(
			'id'		=> 'catchadaptive-header-image',
			'value' 	=> 'enable',
			'label' 	=> __( 'Enable', 'catch-adaptive-pro' ),
		),
		'disable' => array(
			'id'		=> 'catchadaptive-header-image',
			'value' 	=> 'disable',
			'label' 	=> __( 'Disable', 'catch-adaptive-pro' )
		)
	);
	return apply_filters( 'header_featured_image_options', $header_featured_image_options );
}


/**
 * Returns an array of featured content background image positions
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_background_display_positions() {
	$options = array(
		'top'    => __( 'Top', 'catch-adaptive-pro' ),
		'bottom' => __( 'Bottom', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_featured_content_background_display_positions', $options );
}


/**
 * Returns an array of featured content background repeat options
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_background_repeat_options() {
	 $options = array(
		'no-repeat' => __( 'No repeat', 'catch-adaptive-pro' ),
		'tile'      => __( 'Tile', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_featured_content_background_repeat_options', $options );
}


/**
 * Returns an array of featured content background attachment options
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_featured_content_background_attachment_options() {
	$options = array(
		'scroll' => __( 'Scroll', 'catch-adaptive-pro' ),
		'fixed'  => __( 'Fixed', 'catch-adaptive-pro' ),
	);
	return apply_filters( 'catchadaptive_featured_content_background_attachment_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_metabox_sidebar_options() {
	$sidebar_options = array(
		'main-sidebar' => array(
			'id'		=> 'catchadaptive-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> __( 'Default Sidebar', 'catch-adaptive-pro' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'catchadaptive-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => __( 'Optional Sidebar One', 'catch-adaptive-pro' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'catchadaptive-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => __( 'Optional Sidebar Two', 'catch-adaptive-pro' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'catchadaptive-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => __( 'Optional Sidebar three', 'catch-adaptive-pro' )
		)
	);
	return apply_filters( 'sidebar_options', $sidebar_options );
}


/**
 * Returns an array of metabox featured image options registered for catchadaptive.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_metabox_featured_image_options() {
	$featured_image_options = array(
		'default' => array(
			'id'		=> 'catchadaptive-featured-image',
			'value' 	=> 'default',
			'label' 	=> __( 'Default', 'catch-adaptive-pro' ),
		),
		'featured' => array(
			'id'		=> 'catchadaptive-featured-image',
			'value' 	=> 'featured',
			'label' 	=> __( 'Featured Image', 'catch-adaptive-pro' )
		),
		'full' => array(
			'id' => 'catchadaptive-featured-image',
			'value' => 'full',
			'label' => __( 'Full Size', 'catch-adaptive-pro' )
		),
		'disable' => array(
			'id' => 'catchadaptive-featured-image',
			'value' => 'disable',
			'label' => __( 'Disable Image', 'catch-adaptive-pro' )
		)
	);
	return apply_filters( 'featured_image_options', $featured_image_options );
}


/**
 * Returns the default options for catchadaptive dark theme.
 *
 * @since Catch Adaptive Pro 1.0
 */
function catchadaptive_default_dark_color_options() {
	$default_dark_color_options = array(
		//Basic Color Options
		'background_color'									=> '#202020',
		'text_color'										=> '#bebebe',
		'link_color'										=> '#a92f41',
		'link_hover_color'									=> '#bebebe',

		//Header Color Options
		'header_textcolor'									=> '#bebebe',
		'header_background_color'							=> '#000000',
		'site_title_hover_color'							=> '#ffffff',
		'tagline_color'										=> '#bebebe',

		//Content Color Options
		'content_wrapper_background_color'					=> '#202020',
		'content_background_color'							=> '#202020',
		'content_title_color'								=> '#bebebe',
		'content_title_hover_color'							=> '#a92f41',
		'content_meta_color'								=> '#a92f41',
		'content_meta_hover_color'							=> '#bebebe',

		//Sidebar Color Options
		'sidebar_background_color'							=> '#202020',
		'sidebar_widget_title_background_color'				=> '#111111',
		'sidebar_widget_title_color'						=> '#ffffff',
		'sidebar_widget_text_color'							=> '#bebebe',
		'sidebar_widget_link_color'							=> '#a92f41',

		//Pagination Color Options //Need to check in details after
		'pagination_background_color'						=> '#202020',
		'pagination_hover_background_color'					=> '#202020',
		'pagination_text_color'								=> '#bebebe',
		'pagination_link_color'								=> '#a92f41',
		'pagination_hover_active_color'						=> '#ffffff',
		'numeric_infinite_scroll_background_color'			=> '#dddddd',
		'numeric_infinite_scroll_hover_background_color'	=> '#ffffff',
		'numeric_infinite_scroll_text_color'				=> '#000000',
		'numeric_infinite_scroll_hover_text_color'			=> '#000000',

		//Footer Color Options
		'footer_background_color'							=> '#000000',
		'footer_text_color'									=> '#dddddd',
		'footer_link_color'									=> '#dddddd',
		'footer_link_hover_color'							=> '#ffffff',
		'footer_sidebar_area_background_color'				=> '#000000',
		'footer_widget_background_color'					=> '#000000',
		'footer_widget_title_background_color'				=> '#202020',
		'footer_widget_title_color'							=> '#ffffff',
		'footer_widget_text_color'							=> '#bebebe',
		'footer_widget_link_color'							=> '#a92f41',
		'footer_widget_link_hover_color'					=> '#bebebe',

		//Promotion Headline Color Options
		'promotion_headline_background_color'				=> '#000000',
		'promotion_headline_text_color'						=> '#bebebe',
		'promotion_headline_link_color'						=> '#a92f41',
		'promotion_headline_button_background_color'		=> '#a92f41',
		'promotion_headline_button_text_color'				=> '#ffffff',
		'promotion_headline_button_hover_background_color'	=> '#942938',
		'promotion_headline_button_hover_text_color'		=> '#ffffff',
		'promotion_headline_border_color'					=> '#ffffff',

		//Scrollup Color Options
		'scrollup_background_color'							=> '#dddddd',
		'scrollup_hover_background_color'					=> '#ffffff',
		'scrollup_text_color'								=> '#000000',
		'scrollup_hover_text_color'							=> '#000000',

		//Featured Slider Color Options
		'slider_background_color'							=> '#000000',
		'slider_text_color'									=> '#ffffff',
		'slider_link_color'									=> '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'					=> '#ffffff',
		'featured_content_title_color'						=> '#ffffff',
		'featured_content_text_color'						=> '#ffffff',
		'featured_content_link_color'						=> '#21759b',

		//Primary Menu Color Options
		'menu_background_color'								=> '#444444',
		'menu_color'										=> '#dddddd',
		'hover_active_background_color'						=> '#444444',
		'hover_active_text_color'							=> '#aaaaaa',
		'sub_menu_background_color'							=> '#444444',
		'sub_menu_text_color'								=> '#dddddd',

		//Secondary Menu Color Options
		'secondary_menu_background_color'					=> '#111111',
		'secondary_menu_color'								=> '#cccccc',
		'secondary_hover_active_background_color'			=> '#111111',
		'secondary_hover_active_text_color'					=> '#ffffff',
		'secondary_sub_menu_background_color'				=> '#111111',
		'secondary_sub_menu_text_color'						=> '#cccccc',

		//Footer Menu Color Options
		'footer_menu_background_color'						=> '#111111',
		'footer_menu_color'									=> '#666666',
		'footer_hover_active_background_color'				=> '#111111',
		'footer_hover_active_text_color'					=> '#cccccc',
	);

	return apply_filters( 'catchadaptive_default_dark_color_options', $default_dark_color_options );
}


/**
 * Checks if there are options already present from Catch Adaptive free version and adds it to the Catch Adaptive Pro theme options
 *
 * @since Catch Adaptive Pro 1.0
 * @hook after_theme_switch
 */
function catchadaptive_setup_options() {
	//Perform action only if theme_mods_theme_mods_catchbase-pro does not exist
	if ( !get_option( 'theme_mods_catch-adaptive-pro' ) ) {
		//Perform action only if theme_mods_catchbase free version exists
		if ( $catchadaptive_free_options = get_option ( 'theme_mods_catch-adaptive' ) ) {
			update_option('theme_mods_catch-adaptive-pro', $catchadaptive_free_options );
		}
	}
}
add_action( 'after_switch_theme', 'catchadaptive_setup_options' );
