<?php
/**
 * The template for displaying custom menus
 *
 * @package Catch Themes
 * @subpackage Catch Adaptive Pro
 * @since Catch Adaptive Pro 1.0
 */

if ( ! defined( 'CATCHADAPTIVE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


if ( ! function_exists( 'catchadaptive_primary_menu' ) ) :
/**
 * Shows the Primary Menu
 *
 * default load in sidebar-header.php
 */
function catchadaptive_primary_menu() {
    $options  = catchadaptive_get_theme_options();
    ?>
	<nav class="nav-primary" role="navigation">
        <div class="wrapper">
            <div class="screen-reader-text skip-link"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'catch-adaptive-pro' ); ?>"><?php _e( 'Skip to content', 'catch-adaptive-pro' ); ?></a></div>
            <?php
                $flag = 1;

                if ( '1' != $options['primary_menu_disable'] ) {
                    if ( has_nav_menu( 'primary' ) ) {
                        $classes = "mobile-menu-anchor primary-menu";
                    }
                    else {
                        $classes = "mobile-menu-anchor page-menu";
                    }
                }
                elseif ( has_nav_menu( 'secondary' ) ) {
                    $classes = "mobile-menu-anchor secondary-menu";
                }
                else {
                    $classes = "mobile-menu-anchor displaynone";

                    $flag = 0;
                }

                if ( $flag ) {
                    ?>

                    <div id="mobile-header-left-menu" class="<?php echo $classes; ?>">
                        <a href="#mobile-header-left-nav" id="header-left-menu" class="genericon genericon-menu">
                            <span class="mobile-menu-text"><?php _e( 'Menu', 'catch-adaptive-pro' );?></span>
                        </a>
                    </div><!-- #mobile-header-menu -->

                    <?php
                }

                $logo_alt = ( '' != $options['logo_alt_text'] ) ? $options['logo_alt_text'] : get_bloginfo( 'name', 'display' );

                if ( isset( $options['logo_icon'] ) &&  $options['logo_icon'] != '' &&  !empty( $options['logo_icon'] ) ){
                     echo '<div id="logo-icon"><a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" rel="home">
                        <img src="' . esc_url( $options['logo_icon'] ) . '" alt="' . esc_attr( $logo_alt ). '">
                    </a></div>';
                }

                if ( '1' != $options['primary_menu_disable'] ) {
                    echo '<h3 class="assistive-text">' . __( 'Primary Menu', 'catch-adaptive-pro' ) . '</h3>';

                    if ( has_nav_menu( 'primary' ) ) {
                        $catchadaptive_primary_menu_args = array(
                            'theme_location'    => 'primary',
                            'menu_class'        => 'menu catchadaptive-nav-menu',
                            'container'         => false
                        );
                        wp_nav_menu( $catchadaptive_primary_menu_args );
                    }
                    else {
                        wp_page_menu( array( 'menu_class'  => 'menu catchadaptive-nav-menu' ) );
                    }
                }

                if ( '1' != $options['header_toggle_disable'] ) {
                    if ( is_active_sidebar( 'header-toggle' ) ) {
                        $toggleclass = 'genericon-hierarchy';
                    }
                    else {
                        $toggleclass = 'genericon-search';
                    }
                    ?>
                    <div id="header-toggle" class="genericon <?php echo $toggleclass; ?>">
                        <a class="screen-reader-text" href="#header-toggle-sidebar"><?php _e( 'Header Toggle', 'catch-adaptive-pro' ); ?></a>
                    </div>
                    <?php
                }
                elseif ( '1' != $options['primary_menu_disable'] && has_nav_menu( 'secondary' ) ) {
                    $classes = "mobile-menu-anchor secondary-menu";
                    // Header Right Mobile Menu Anchor
                    ?>
                    <div id="mobile-header-right-menu" class="<?php echo $classes; ?>">
                        <a href="#mobile-header-right-nav" id="header-right-menu" class="genericon genericon-menu">
                            <span class="mobile-menu-text"><?php _e( 'Menu', 'catch-adaptive-pro' );?></span>
                        </a>
                    </div><!-- #mobile-header-menu -->
                    <?php
                }
                ?>
    	</div><!-- .wrapper -->
    </nav><!-- .nav-primary -->
        <?php
}
endif; //catchadaptive_primary_menu
add_action( 'catchadaptive_header', 'catchadaptive_primary_menu', 30 );


if ( ! function_exists( 'catchadaptive_secondary_menu' ) ) :
/**
 * Shows the Secondary Menu
 *
 * default load in sidebar-header.php
 */
function catchadaptive_secondary_menu() {
    if ( has_nav_menu( 'secondary' ) ) {
	?>
    	<nav class="nav-secondary" role="navigation">
            <div class="wrapper">
                <h3 class="assistive-text"><?php _e( 'Secondary Menu', 'catch-adaptive-pro' ); ?></h3>
                <div class="screen-reader-text skip-link"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'catch-adaptive-pro' ); ?>"><?php _e( 'Skip to content', 'catch-adaptive-pro' ); ?></a></div>
                <?php
                    $catchadaptive_secondary_menu_args = array(
                        'theme_location'    => 'secondary',
                        'menu_class' => 'menu catchadaptive-nav-menu'
                    );
                    wp_nav_menu( $catchadaptive_secondary_menu_args );
                ?>
        	</div><!-- .wrapper -->
        </nav><!-- .nav-secondary -->

<?php
    }
}
endif; //catchadaptive_secondary_menu
add_action( 'catchadaptive_before_content', 'catchadaptive_secondary_menu', 20 );


if ( ! function_exists( 'catchadaptive_footer_menu' ) ) :
/**
 * Shows the Footer Menu
 *
 * default load in sidebar-header.php
 */
function catchadaptive_footer_menu() {
	if ( has_nav_menu( 'footer' ) ) {
    ?>
	<nav class="nav-footer" role="navigation">
        <div class="wrapper">
            <h3 class="assistive-text"><?php _e( 'Footer Menu', 'catch-adaptive-pro' ); ?></h3>
            <div class="screen-reader-text skip-link"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'catch-adaptive-pro' ); ?>"><?php _e( 'Skip to content', 'catch-adaptive-pro' ); ?></a></div>
            <?php
                $catchadaptive_footer_menu_args = array(
                    'theme_location'    => 'footer',
                    'menu_class'        => 'menu catchadaptive-nav-menu',
                    'depth'             =>  1
                );
                wp_nav_menu( $catchadaptive_footer_menu_args );
            ?>
    	</div><!-- .wrapper -->
    </nav><!-- .nav-footer -->
<?php
    }
}
endif; //catchadaptive_footer_menu
add_action( 'catchadaptive_footer', 'catchadaptive_footer_menu', 50 );


if ( ! function_exists( 'catchadaptive_mobile_menus' ) ) :
/**
 * This function loads Mobile Menus
 *
 * @get the data value from theme options
 * @uses catchadaptive_after action to add the code in the footer
 */
function catchadaptive_mobile_menus() {
    //Getting Ready to load options data
    $options                    = catchadaptive_get_theme_options();

   // Check Header Left Mobile Menu
   if ( '1' != $options['primary_menu_disable'] ) :
       $count = '1';
       $location = 'primary';
   elseif ( has_nav_menu( 'secondary' ) ) :
       $count = '1';
       $location = 'secondary';
   else :
       $count = '0';
       $location = 'none';
   endif;

   if ( '0' == $count ) {
        return;
   }

    echo '<nav id="mobile-header-left-nav" class="mobile-menu" role="navigation">';

        if ( '1' == $count ) :
            $args = array(
                'theme_location'    => $location,
                'container'         => false,
                'items_wrap'        => '<ul id="header-left-nav" class="menu ' . $location .  '">%3$s</ul>'
            );
            wp_nav_menu( $args );
        else :
            wp_page_menu( array( 'menu_class'  => 'menu' ) );
        endif;
    echo '</nav><!-- #mobile-header-left-nav -->';


    // Check Header Right Mobile Menu ( only for Header right and Secondary )
    if ( '1' == $options['primary_menu_disable'] ) :
        return;
    elseif ( has_nav_menu( 'secondary' ) &&  '1' == $options['header_toggle_disable'] ) :
        $count2 = '1';
        $location2 = 'secondary';
    else :
        $count2 = '0';
        $location2 = 'none';
    endif;

    if ( '1' == $count2 ) :
        echo '<nav id="mobile-header-right-nav" class="mobile-menu" role="navigation">';
            $args = array(
                'theme_location'    => $location2,
                'container'         => false,
                'items_wrap'        => '<ul id="header-left-nav" class="menu ' . $location2 . '">%3$s</ul>'
            );
            wp_nav_menu( $args );
        echo '</nav><!-- #mobile-header-right-nav -->';
    endif;
}
endif; //catchadaptive_mobile_menus

add_action( 'catchadaptive_after', 'catchadaptive_mobile_menus', 20 );