<?php
/**
 * Active callbacks for Theme/Customzer Options
 *
 * @package Catch Themes
 * @subpackage Catch Adaptive
 * @since Catch Adaptive 1.0
 */

if ( ! defined( 'CATCHADAPTIVE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

if ( ! function_exists( 'catchadaptive_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_demo_slider_inactive( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && !( 'demo-featured-slider' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-post-slider' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-page-slider' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-category-slider' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-image-slider' == $type ) );
	}
endif;

if ( ! function_exists( 'catchadaptive_is_featured_content_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_demo_featured_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_demo_featured_content_inactive( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is not demo content
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && !( 'demo-featured-content' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_post_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-post-content' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_page_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-page-content' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_category_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-category-content' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_image_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchadaptive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) ) && ( 'featured-image-content' == $type ) );
	}
endif;


if ( ! function_exists( 'catchadaptive_is_featured_content_background_image_enabled' ) ) :
	/**
	* Return true if featured content background image is not disabled
	*
	* @since  Catch Adaptive 1.0
	*/
	function catchadaptive_is_featured_content_background_image_enabled( $control ) {
		return !$control->manager->get_setting( 'catchadaptive_theme_options[featured_content_disable_background_image]' )->value();
	}
endif;