<?php
/**
 * The template for adding Featured Content Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Catch Adaptive Pro
 * @since Catch Adaptive Pro 1.0
 */

if ( ! defined( 'CATCHADAPTIVE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
	// Featured Content Options
	$wp_customize->add_panel( 'catchadaptive_featured_content_options', array(
	    'capability'     => 'edit_theme_options',
		'description'    => __( 'Options for Featured Content', 'catch-adaptive-pro' ),
	    'priority'       => 400,
	    'title'    		 => __( 'Featured Content', 'catch-adaptive-pro' ),
	) );


	$wp_customize->add_section( 'catchadaptive_featured_content', array(
		'panel'			=> 'catchadaptive_featured_content_options',
		'priority'		=> 1,
		'title'			=> __( 'Featured Content Options', 'catch-adaptive-pro' ),
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_option'],
		'sanitize_callback' => 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_option]', array(
		'choices'  	=> catchadaptive_featured_slider_content_options(),
		'label'    	=> __( 'Enable Featured Content on', 'catch-adaptive-pro' ),
		'priority'	=> '1',
		'section'  	=> 'catchadaptive_featured_content',
		'settings' 	=> 'catchadaptive_theme_options[featured_content_option]',
		'type'	  	=> 'select',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_layout'],
		'sanitize_callback' => 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_layout]', array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'choices'  			=> catchadaptive_featured_content_layout_options(),
		'label'    			=> __( 'Select Featured Content Layout', 'catch-adaptive-pro' ),
		'priority'			=> '2',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_layout]',
		'type'	  			=> 'select',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_position]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_position'],
		'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_position]', array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'label'				=> __( 'Check to Move above Footer', 'catch-adaptive-pro' ),
		'priority'			=> '3',
		'section'  			=> 'catchadaptive_featured_content',
		'settings'			=> 'catchadaptive_theme_options[featured_content_position]',
		'type'				=> 'checkbox',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_slider]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_slider'],
		'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_slider]', array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'label'				=> __( 'Check to Enable Content Sliding effect', 'catch-adaptive-pro' ),
		'priority'			=> '4',
		'section'  			=> 'catchadaptive_featured_content',
		'settings'			=> 'catchadaptive_theme_options[featured_content_slider]',
		'type'				=> 'checkbox',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_type'],
		'sanitize_callback'	=> 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_type]', array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'choices'  			=> catchadaptive_featured_content_types(),
		'label'    			=> __( 'Select Content Type', 'catch-adaptive-pro' ),
		'priority'			=> '5',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_type]',
		'type'	  			=> 'select',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_headline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_headline'],
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_headline]' , array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'description'		=> __( 'Leave field empty if you want to remove Headline', 'catch-adaptive-pro' ),
		'label'    			=> __( 'Headline for Featured Content', 'catch-adaptive-pro' ),
		'priority'			=> '6',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_headline]',
		'type'	   			=> 'text',
		)
	);

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_subheadline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_subheadline'],
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_subheadline]' , array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'description'		=> __( 'Leave field empty if you want to remove Sub-headline', 'catch-adaptive-pro' ),
		'label'    			=> __( 'Sub-headline for Featured Content', 'catch-adaptive-pro' ),
		'priority'			=> '7',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_subheadline]',
		'type'	   			=> 'text',
		)
	);

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_number]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_number'],
		'sanitize_callback'	=> 'catchadaptive_sanitize_number_range',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_number]' , array(
		'active_callback'	=> 'catchadaptive_is_demo_featured_content_inactive',
		'description'		=> __( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'catch-adaptive-pro' ),
		'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 20,
						            'step'  => 1,
						        	),
		'label'    			=> __( 'No of Featured Content', 'catch-adaptive-pro' ),
		'priority'			=> '8',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_number]',
		'type'	   			=> 'number',
		)
	);

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_enable_title]', array(
	        'default'			=> $defaults['featured_content_enable_title'],
			'sanitize_callback'	=> 'catchadaptive_sanitize_checkbox',
		) );

	$wp_customize->add_control(  'catchadaptive_theme_options[featured_content_enable_title]', array(
		'active_callback'	=> 'catchadaptive_is_demo_featured_content_inactive',
		'label'				=> __( 'Check to Enable Title', 'catch-adaptive-pro' ),
        'priority'			=> '9',
		'section'   		=> 'catchadaptive_featured_content',
        'settings'  		=> 'catchadaptive_theme_options[featured_content_enable_title]',
		'type'				=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_show]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_show'],
		'sanitize_callback'	=> 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_show]', array(
		'active_callback'	=> 'catchadaptive_is_demo_featured_content_inactive',
		'choices'  			=> catchadaptive_featured_content_show(),
		'label'    			=> __( 'Display Content', 'catch-adaptive-pro' ),
		'priority'			=> '9.1',
		'section'  			=> 'catchadaptive_featured_content',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_show]',
		'type'	  			=> 'select',
	) );

	//loop for featured post content
	for ( $i=1; $i <=  $options['featured_content_number'] ; $i++ ) {
		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'catchadaptive_sanitize_page',
		)
	);

		$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_post_'. $i .']', array(
			'active_callback'	=> 'catchadaptive_is_featured_post_content_active',
			'input_attrs' 		=> array(
				'style' => 'width: 100px;'
			),
			'label'    			=> __( 'Featured Post', 'catch-adaptive-pro' ) . ' ' . $i ,
			'priority'			=>  '11' . $i,
			'section'  			=> 'catchadaptive_featured_content',
			'settings' 			=> 'catchadaptive_theme_options[featured_content_post_'. $i .']',
			'type'	   			=> 'text',
			)
		);
	}

	//loop for featured page sliders
	for ( $i=1; $i <= $options['featured_content_number'] ; $i++ ) {
		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_page_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'catchadaptive_sanitize_page',
		) );

		$wp_customize->add_control( 'catchadaptive_featured_content_page_'. $i .'', array(
			'active_callback'	=> 'catchadaptive_is_featured_page_content_active',
			'label'    			=> __( 'Featured Page', 'catch-adaptive-pro' ) . ' ' . $i ,
			'priority'			=> '12' . $i,
			'section'  			=> 'catchadaptive_featured_content',
			'settings' 			=> 'catchadaptive_theme_options[featured_content_page_'. $i .']',
			'type'	   			=> 'dropdown-pages',
		) );
	}

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_select_category]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'catchadaptive_sanitize_category_list',
	) );

	$wp_customize->add_control( new Catchadaptive_Customize_Dropdown_Categories_Control( $wp_customize, 'catchadaptive_featured_content_select_category', array(
		'active_callback'	=> 'catchadaptive_is_featured_category_content_active',
        'label'   			=> __( 'Select Categories', 'catch-adaptive-pro' ),
        'name' 				=> 'catchadaptive_theme_options[featured_content_select_category]',
        'section'  			=> 'catchadaptive_featured_content',
        'settings' 			=> 'catchadaptive_theme_options[featured_content_select_category]',
        'type'     			=> 'dropdown-categories',
    ) ) );

	$priority	=	13;
	//loop for featured image content
	for( $i = 1; $i <= $options['featured_content_number'] ; $i++ ){
		if ( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
			$priority++;

		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Catchadaptive_Note_Control( $wp_customize, 'featured_content_note_'. $i, array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
	        'label'				=> __( 'Featured Content #', 'catch-adaptive-pro' ) .  $i,
			'priority'			=> $priority . '.' . $i,
	        'section'  			=> 'catchadaptive_featured_content',
	        'settings'			=> 'catchadaptive_theme_options[featured_content_note_'. $i .']',
	        'type'     			=> 'description',
   		) ) );

		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_image_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'catchadaptive_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
			'label'				=> __( 'Image', 'catch-adaptive-pro' ),
	        'priority'			=> $priority . '.' . $i .$i,
			'section'   		=> 'catchadaptive_featured_content',
	        'settings'  		=> 'catchadaptive_theme_options[featured_content_image_'. $i .']',
		) ) );

		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_link_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'catchadaptive_theme_options[featured_content_link_'. $i .']', array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
			'label'				=> __( 'Link', 'catch-adaptive-pro' ),
	        'priority'			=> $priority . '.' .$i . $i  . $i ,
			'section'   		=> 'catchadaptive_featured_content',
	        'settings'  		=> 'catchadaptive_theme_options[featured_content_link_'. $i .']',
		) );

		$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_target_'. $i .']', array(
	        'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'catchadaptive_sanitize_checkbox',
		) );

		$wp_customize->add_control(  'catchadaptive_theme_options[featured_content_target_'. $i .']', array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
			'label'				=> __( 'Check to Open Link in New Window/Tab', 'catch-adaptive-pro' ),
	        'priority'			=> $priority . '.' .$i  .$i  . $i . $i,
			'section'   		=> 'catchadaptive_featured_content',
	        'settings'  		=> 'catchadaptive_theme_options[featured_content_target_'. $i .']',
			'type'				=> 'checkbox',
	    ) );

	    $wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_title_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'catchadaptive_theme_options[featured_content_title_'. $i .']', array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
			'label'				=> __( 'Title', 'catch-adaptive-pro' ),
	        'priority'			=> $priority . '.' .$i .  $i.  $i .$i . $i,
			'section'   		=> 'catchadaptive_featured_content',
	        'settings'  		=> 'catchadaptive_theme_options[featured_content_title_'. $i .']',
			'type'				=> 'text',
	    ) );

	    $wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_content_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'wp_kses_post',
		) );

		$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_content_'. $i .']', array(
			'active_callback'	=> 'catchadaptive_is_featured_image_content_active',
			'label'				=> __( 'Content', 'catch-adaptive-pro' ),
	        'priority'			=> $priority . '.' . $i . $i .  $i . $i . $i . $i,
			'section'   		=> 'catchadaptive_featured_content',
	        'settings'  		=> 'catchadaptive_theme_options[featured_content_content_'. $i .']',
			'type'				=> 'textarea',
	    ) );
	}

	$wp_customize->add_section( 'catchadaptive_featured_content_background_settings', array(
		'active_callback'	=> 'catchadaptive_is_featured_content_active',
		'panel'				=> 'catchadaptive_featured_content_options',
		'priority'			=> 3,
		'title'				=> __( 'Featured Content Background Settings', 'catch-adaptive-pro' ),
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_disable_background_image]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_disable_background_image'],
		'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_disable_background_image]', array(
		'label'				=> __( 'Check to disable background image', 'catch-adaptive-pro' ),
		'priority'			=> '0.5',
		'section'  			=> 'catchadaptive_featured_content_background_settings',
		'settings'			=> 'catchadaptive_theme_options[featured_content_disable_background_image]',
		'type'				=> 'checkbox',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_background_image]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['featured_content_background_image'],
			'sanitize_callback'	=> 'catchadaptive_sanitize_image',
		) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'catchadaptive_theme_options[featured_content_background_image]', array(
		'active_callback'	=>'catchadaptive_is_featured_content_background_image_enabled',
		'label'				=> __( 'Select/Add Background Image', 'catch-adaptive-pro' ),
		'priority'			=> '1',
		'section'   		=> 'catchadaptive_featured_content_background_settings',
        'settings'  		=> 'catchadaptive_theme_options[featured_content_background_image]',
	) ) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_background_display_position]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_background_display_position'],
		'sanitize_callback' => 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_background_display_position]', array(
		'active_callback'	=>'catchadaptive_is_featured_content_background_image_enabled',
		'choices'  			=> catchadaptive_featured_content_background_display_positions(),
		'label'    			=> __( 'Display Position', 'catch-adaptive-pro' ),
		'priority'			=> '2',
		'section'  			=> 'catchadaptive_featured_content_background_settings',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_background_display_position]',
		'type'	  			=> 'radio',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_background_repeat]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_background_repeat'],
		'sanitize_callback' => 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_background_repeat]', array(
		'active_callback'	=>'catchadaptive_is_featured_content_background_image_enabled',
		'choices'  			=> catchadaptive_featured_content_background_repeat_options(),
		'label'    			=> __( 'Repeat', 'catch-adaptive-pro' ),
		'priority'			=> '2',
		'section'  			=> 'catchadaptive_featured_content_background_settings',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_background_repeat]',
		'type'	  			=> 'radio',
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[featured_content_background_attachment]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_background_attachment'],
		'sanitize_callback' => 'catchadaptive_sanitize_select',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[featured_content_background_attachment]', array(
		'active_callback'	=>'catchadaptive_is_featured_content_background_image_enabled',
		'choices'  			=> catchadaptive_featured_content_background_attachment_options(),
		'label'    			=> __( 'Attachment', 'catch-adaptive-pro' ),
		'priority'			=> '2',
		'section'  			=> 'catchadaptive_featured_content_background_settings',
		'settings' 			=> 'catchadaptive_theme_options[featured_content_background_attachment]',
		'type'	  			=> 'radio',
	) );
// Featured Content Setting End