<?php
/**
* The template for adding additional theme options in Customizer
*
* @package Catch Themes
* @subpackage Catch Adaptive Pro
* @since Catch Adaptive Pro 1.0
*/

$wp_customize->add_panel( 'catchadaptive_theme_options', array(
	'description' => __( 'Basic theme Options', 'catch-adaptive-pro' ),
	'capability'  => 'edit_theme_options',
	'priority'    => 200,
	'title'       => __( 'Theme Options', 'catch-adaptive-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'catchadaptive_breadcumb_options', array(
	'description' => __( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'catch-adaptive-pro' ),
	'panel'       => 'catchadaptive_theme_options',
	'title'       => __( 'Breadcrumb Options', 'catch-adaptive-pro' ),
	'priority'    => 201,
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[breadcumb_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_option'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[breadcumb_option]', array(
	'label'    => __( 'Check to enable Breadcrumb', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_breadcumb_options',
	'settings' => 'catchadaptive_theme_options[breadcumb_option]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[breadcumb_onhomepage]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_onhomepage'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[breadcumb_onhomepage]', array(
	'label'    => __( 'Check to enable Breadcrumb on Homepage', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_breadcumb_options',
	'settings' => 'catchadaptive_theme_options[breadcumb_onhomepage]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[breadcumb_seperator]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[breadcumb_seperator]', array(
	'input_attrs' => array(
    		'style' => 'width: 40px;'
		),
	'label'    	=> __( 'Separator between Breadcrumbs', 'catch-adaptive-pro' ),
	'section' 	=> 'catchadaptive_breadcumb_options',
	'settings' 	=> 'catchadaptive_theme_options[breadcumb_seperator]',
	'type'     	=> 'text'
	)
);
	// Breadcrumb Option End

	// Comment Option
$wp_customize->add_section( 'catchadaptive_comment_option', array(
	'description'	=> __( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'catch-adaptive-pro' ),
	'panel' 		=> 'catchadaptive_theme_options',
	'priority'		=> 202,
	'title'   		=> __( 'Comment Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[comment_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[comment_option]', array(
		'choices'  	=> catchadaptive_comment_options(),
		'label'		=> __( 'Comment Option', 'catch-adaptive-pro' ),
        'priority'	=> 1,
		'section'   => 'catchadaptive_comment_option',
        'settings'  => 'catchadaptive_theme_options[comment_option]',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[disable_notes]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_notes'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[disable_notes]', array(
	'label'		=> __( 'Check to Disable Notes', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_comment_option',
    'settings'  => 'catchadaptive_theme_options[disable_notes]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[disable_website_field]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[disable_website_field]', array(
	'label'		=> __( 'Check to Disable Website Field', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_comment_option',
    'settings'  => 'catchadaptive_theme_options[disable_website_field]',
	'type'		=> 'checkbox',
) );
	// Comment End

/**
 * Do not show Custom CSS option from WordPress 4.7 onwards
 * @remove if block when WP 5.0 is released
 */
if ( !function_exists( 'wp_update_custom_css_post' ) ) {
   	// Custom CSS Option
	$wp_customize->add_section( 'catchadaptive_custom_css', array(
		'description'	=> __( 'Custom/Inline CSS', 'catch-adaptive-pro'),
		'panel'  		=> 'catchadaptive_theme_options',
		'priority' 		=> 203,
		'title'    		=> __( 'Custom CSS Options', 'catch-adaptive-pro' ),
	) );

	$wp_customize->add_setting( 'catchadaptive_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'catchadaptive_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[custom_css]', array(
		'label'		=> __( 'Enter Custom CSS', 'catch-adaptive-pro' ),
        'priority'	=> 1,
		'section'   => 'catchadaptive_custom_css',
        'settings'  => 'catchadaptive_theme_options[custom_css]',
		'type'		=> 'textarea',
	) );
   	// Custom CSS End
}

	// Excerpt Options
$wp_customize->add_section( 'catchadaptive_excerpt_options', array(
	'panel'  	=> 'catchadaptive_theme_options',
	'priority' 	=> 204,
	'title'    	=> __( 'Excerpt Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[excerpt_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[excerpt_length]', array(
	'description' => __('Excerpt length. Default is 40 words', 'catch-adaptive-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => __( 'Excerpt Length (words)', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_excerpt_options',
	'settings' => 'catchadaptive_theme_options[excerpt_length]',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'catchadaptive_theme_options[excerpt_more_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[excerpt_more_text]', array(
	'label'    => __( 'Read More Text', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_excerpt_options',
	'settings' => 'catchadaptive_theme_options[excerpt_more_text]',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'catchadaptive_feed_redirect', array(
	'panel'			=> 'catchadaptive_theme_options',
	'description'	=> __( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'catch-adaptive-pro' ),
	'priority' 		=> 205,
	'title'    		=> __( 'Feed Redirect', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[feed_redirect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[feed_redirect]', array(
	'label'    => __( 'Feed Redirect', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_feed_redirect',
	'settings' => 'catchadaptive_theme_options[feed_redirect]',
	'type'	   => 'text',
) );
// Feed Redirect End

// Fixed Header Top Options
$wp_customize->add_section( 'catchadaptive_fixed_header_top', array(
	'panel'    => 'catchadaptive_theme_options',
	'priority' => 206,
	'title'    => __( 'Header Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[logo_icon]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'catchadaptive_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'catchadaptive_theme_options[logo_icon]', array(
	'label'		 	=> __( 'Select/Add Logo Icon', 'catch-adaptive-pro' ),
	'section'    	=> 'catchadaptive_fixed_header_top',
    'settings'   	=> 'catchadaptive_theme_options[logo_icon]',
) ) );

$wp_customize->add_setting( 'catchadaptive_theme_options[primary_menu_disable]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['primary_menu_disable'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[primary_menu_disable]', array(
	'label'    => __( 'Check to disable Primary Menu', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_fixed_header_top',
	'settings' => 'catchadaptive_theme_options[primary_menu_disable]',
	'type'     => 'checkbox',
) );


$wp_customize->add_setting( 'catchadaptive_theme_options[header_toggle_disable]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['header_toggle_disable'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[header_toggle_disable]', array(
	'label'    => __( 'Check to disable Header Toggle & Search', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_fixed_header_top',
	'settings' => 'catchadaptive_theme_options[header_toggle_disable]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[disable_header_sidebar]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_header_sidebar'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[disable_header_sidebar]', array(
	'label'    	=> __( 'Check to disable Header Sidebar', 'catch-adaptive-pro' ),
	'section'  	=> 'catchadaptive_fixed_header_top',
	'settings' 	=> 'catchadaptive_theme_options[disable_header_sidebar]',
	'type'     	=> 'checkbox',
) );
// Fixed Header Top Option End

// Font Family Options
$wp_customize->add_section( 'catchadaptive_font_family', array(
	'panel'  => 'catchadaptive_theme_options',
	'priority'	=> 207,
	'title'    	=> __( 'Font Family Options', 'catch-adaptive-pro' ),
) );

$avaliable_fonts = catchadaptive_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
									'title_font' 		=> __( 'Site Title Font Family', 'catch-adaptive-pro' ),
									'body_font' 		=> __( 'Default Font Family', 'catch-adaptive-pro' ),
									'tagline_font' 		=> __( 'Site Tagline Font Family', 'catch-adaptive-pro' ),
									'content_title_font'=> __( 'Content Title Font Family', 'catch-adaptive-pro' ),
									'content_font' 		=> __( 'Content Body Font Family', 'catch-adaptive-pro' ),
									'headings_font' 	=> __( 'Headings Tags from h1 to h6 Font Family', 'catch-adaptive-pro' )
								);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( 'catchadaptive_theme_options['. $key . ']', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'sanitize_key',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options['. $key . ']', array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'catchadaptive_font_family',
		'settings' => 'catchadaptive_theme_options['. $key . ']',
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'catchadaptive_theme_options[reset_typography]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[reset_typography]', array(
	'description'	=> __( 'Refresh the page after save to view full effects.', 'catch-adaptive-pro' ),
	'label'		=> __( 'Check to reset fonts', 'catch-adaptive-pro' ),
	'section'	=> 'catchadaptive_font_family',
	'settings'	=> 'catchadaptive_theme_options[reset_typography]',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'catchadaptive_footer_options', array(
	'description'	=> __( 'You can either add html or plain text', 'catch-adaptive-pro'),
	'panel'  => 'catchadaptive_theme_options',
	'priority' 		=> 208,
	'title'    		=> __( 'Footer Editor Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[footer_left_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_left_content'],
	'sanitize_callback'	=> 'catchadaptive_sanitize_footer_code',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[footer_left_content]', array(
		'description' 	=> __( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'catch-adaptive-pro' ),
		'label'			=> __( 'Footer Left Content', 'catch-adaptive-pro' ),
        'priority'		=> 1,
		'section'   	=> 'catchadaptive_footer_options',
        'settings'  	=> 'catchadaptive_theme_options[footer_left_content]',
		'type'			=> 'textarea',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[footer_right_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_right_content'],
	'sanitize_callback'	=> 'catchadaptive_sanitize_footer_code',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[footer_right_content]', array(
		'label'		=> __( 'Footer Right Content', 'catch-adaptive-pro' ),
        'priority'	=> 2,
		'section'   => 'catchadaptive_footer_options',
        'settings'  => 'catchadaptive_theme_options[footer_right_content]',
		'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[reset_footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[reset_footer_content]', array(
	'description' => __( 'Refresh the page after save to view full effects.', 'catch-adaptive-pro' ),'label'		=> __( 'Check to reset Footer Content', 'catch-adaptive-pro' ),
	'priority'    => 3,
	'settings'    => 'catchadaptive_theme_options[reset_footer_content]',
	'section'     => 'catchadaptive_footer_options',
	'type'        => 'checkbox',
) );
// Footer Options End

//Homepage / Frontpage Options
$wp_customize->add_section( 'catchadaptive_homepage_options', array(
	'description'	=> __( 'Only posts that belong to the categories selected here will be displayed on the front page', 'catch-adaptive-pro' ),
	'panel'			=> 'catchadaptive_theme_options',
	'priority' 		=> 209,
	'title'   	 	=> __( 'Homepage / Frontpage Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[front_page_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'catchadaptive_sanitize_category_list',
) );

$wp_customize->add_control( new Catchadaptive_Customize_Dropdown_Categories_Control( $wp_customize, 'catchadaptive_theme_options[front_page_category]', array(
    'label'   	=> __( 'Select Categories', 'catch-adaptive-pro' ),
    'name'	 	=> 'catchadaptive_theme_options[front_page_category]',
	'priority'	=> '6',
    'section'  	=> 'catchadaptive_homepage_options',
    'settings' 	=> 'catchadaptive_theme_options[front_page_category]',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End


// Layout Options
$wp_customize->add_section( 'catchadaptive_layout', array(
	'capability' => 'edit_theme_options',
	'panel'      => 'catchadaptive_theme_options',
	'priority'   => 211,
	'title'      => __( 'Layout Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[theme_layout]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['theme_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[theme_layout]', array(
	'choices'  => catchadaptive_layouts(),
	'label'    => __( 'Default Layout', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_layout',
	'settings' => 'catchadaptive_theme_options[theme_layout]',
	'type'     => 'select',
) );

if ( class_exists( 'WooCommerce' ) ) {
	$wp_customize->add_setting( 'catchadaptive_theme_options[woocommerce_layout]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['woocommerce_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$wp_customize->add_control( 'catchadaptive_theme_options[woocommerce_layout]', array(
		'choices'  => catchadaptive_layouts(),
		'label'    => __( 'Woocommerce Layout', 'catch-adaptive-pro' ),
		'section'  => 'catchadaptive_layout',
		'settings' => 'catchadaptive_theme_options[woocommerce_layout]',
		'type'     => 'select',
	) );
}

$wp_customize->add_setting( 'catchadaptive_theme_options[content_layout]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['content_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[content_layout]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['content_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[content_layout]', array(
	'choices'  => catchadaptive_get_archive_content_layout(),
	'label'    => __( 'Archive Content Layout', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_layout',
	'settings' => 'catchadaptive_theme_options[content_layout]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[single_post_image_layout]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['single_post_image_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[single_post_image_layout]', array(
		'label'    => __( 'Single Page/Post Image Layout ', 'catch-adaptive-pro' ),
		'section'  => 'catchadaptive_layout',
		'settings' => 'catchadaptive_theme_options[single_post_image_layout]',
		'type'     => 'select',
		'choices'  => catchadaptive_single_post_image_layout_options(),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[hide_archive_meta]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hide_archive_meta'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[hide_archive_meta]', array(
	'label'    => __( 'Check to hide meta information on archive pages', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_layout',
	'settings' => 'catchadaptive_theme_options[hide_archive_meta]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[hide_archive_content]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hide_archive_content'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[hide_archive_content]', array(
	'label'    => __( 'Check to hide excerpt/content on archive pages', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_layout',
	'settings' => 'catchadaptive_theme_options[hide_archive_content]',
	'type'     => 'checkbox',
) );
	// Layout Options End

// Pagination Options
$pagination_type	= $options['pagination_type'];

$catchadaptive_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%1$s">WP-PageNavi Plugin</a>.<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'catch-adaptive-pro' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );

/**
 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled
 */
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
	if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
		$catchadaptive_navigation_description = sprintf( __( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'catch-adaptive-pro' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );
	}
	else {
		$catchadaptive_navigation_description = '';
	}
}
/**
* Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
*/
elseif ( 'numeric' == $pagination_type ) {
	if ( !function_exists( 'wp_pagenavi' ) ) {
		$catchadaptive_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%s">WP-PageNavi Plugin</a>.', 'catch-adaptive-pro' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ) );
	}
	else {
		$catchadaptive_navigation_description = '';
	}
}

$wp_customize->add_section( 'catchadaptive_pagination_options', array(
	'description'	=> $catchadaptive_navigation_description,
	'panel'  		=> 'catchadaptive_theme_options',
	'priority'		=> 212,
	'title'    		=> __( 'Pagination Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[pagination_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_pagination_options', array(
	'choices'  => catchadaptive_get_pagination_types(),
	'label'    => __( 'Pagination type', 'catch-adaptive-pro' ),
	'section'  => 'catchadaptive_pagination_options',
	'settings' => 'catchadaptive_theme_options[pagination_type]',
	'type'	   => 'select',
) );
// Pagination Options End

//Promotion Headline Options
$wp_customize->add_section( 'catchadaptive_promotion_headline_options', array(
	'description'	=> __( 'To disable the fields, simply leave them empty.', 'catch-adaptive-pro' ),
	'panel'			=> 'catchadaptive_theme_options',
	'priority' 		=> 213,
	'title'   	 	=> __( 'Promotion Headline Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_headline_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_headline_option]', array(
	'choices'  	=> catchadaptive_featured_slider_content_options(),
	'label'    	=> __( 'Enable Promotion Headline on', 'catch-adaptive-pro' ),
	'priority'	=> '0.5',
	'section'  	=> 'catchadaptive_promotion_headline_options',
	'settings' 	=> 'catchadaptive_theme_options[promotion_headline_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_headline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_headline]', array(
	'description'	=> __( 'Appropriate Words: 10', 'catch-adaptive-pro' ),
	'label'    	=> __( 'Promotion Headline Text', 'catch-adaptive-pro' ),
	'priority'	=> '1',
	'section' 	=> 'catchadaptive_promotion_headline_options',
	'settings'	=> 'catchadaptive_theme_options[promotion_headline]',
	'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_subheadline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_subheadline]', array(
	'description'	=> __( 'Appropriate Words: 15', 'catch-adaptive-pro' ),
	'label'    	=> __( 'Promotion Subheadline Text', 'catch-adaptive-pro' ),
	'priority'	=> '2',
	'section' 	=> 'catchadaptive_promotion_headline_options',
	'settings'	=> 'catchadaptive_theme_options[promotion_subheadline]',
	'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_headline_button]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_headline_button]', array(
	'description'	=> __( 'Appropriate Words: 3', 'catch-adaptive-pro' ),
	'label'    	=> __( 'Promotion Headline Button Text ', 'catch-adaptive-pro' ),
	'priority'	=> '3',
	'section' 	=> 'catchadaptive_promotion_headline_options',
	'settings'	=> 'catchadaptive_theme_options[promotion_headline_button]',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_headline_url]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_headline_url]', array(
	'label'    	=> __( 'Promotion Headline Link', 'catch-adaptive-pro' ),
	'priority'	=> '4',
	'section' 	=> 'catchadaptive_promotion_headline_options',
	'settings'	=> 'catchadaptive_theme_options[promotion_headline_url]',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[promotion_headline_target]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[promotion_headline_target]', array(
	'label'    	=> __( 'Check to Open Link in New Window/Tab', 'catch-adaptive-pro' ),
	'priority'	=> '5',
	'section'  	=> 'catchadaptive_promotion_headline_options',
	'settings' 	=> 'catchadaptive_theme_options[promotion_headline_target]',
	'type'     	=> 'checkbox',
) );
// Promotion Headline Options End

// Scrollup
$wp_customize->add_section( 'catchadaptive_scrollup', array(
	'panel'    => 'catchadaptive_theme_options',
	'priority' => 215,
	'title'    => __( 'Scrollup Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[disable_scrollup]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[disable_scrollup]', array(
	'label'		=> __( 'Check to disable Scroll Up', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_scrollup',
    'settings'  => 'catchadaptive_theme_options[disable_scrollup]',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'catchadaptive_search_options', array(
	'description'=> __( 'Change default placeholder text in Search.', 'catch-adaptive-pro'),
	'panel'  => 'catchadaptive_theme_options',
	'priority' => 216,
	'title'    => __( 'Search Options', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[search_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[search_text]', array(
	'label'		=> __( 'Default Display Text in Search', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_search_options',
    'settings'  => 'catchadaptive_theme_options[search_text]',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'catchadaptive_single_post_navigation', array(
	'panel'  => 'catchadaptive_theme_options',
	'priority' => 217,
	'title'    => __( 'Single Post Navigation', 'catch-adaptive-pro' ),
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[disable_single_post_navigation]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[disable_single_post_navigation]', array(
	'label'		=> __( 'Check to disable Single Post Navigation', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_single_post_navigation',
    'settings'  => 'catchadaptive_theme_options[disable_single_post_navigation]',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'catchadaptive_update_notifier', array(
	'title'    => __( 'Update Notifier', 'catch-adaptive-pro' ),
	'priority' => 218,
	'panel'    => 'catchadaptive_theme_options',
) );

$wp_customize->add_setting( 'catchadaptive_theme_options[update_notifier]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'catchadaptive_sanitize_checkbox',
) );

$wp_customize->add_control( 'catchadaptive_theme_options[update_notifier]', array(
	'label'		=> __( 'Check to disable update notifications', 'catch-adaptive-pro' ),
	'section'   => 'catchadaptive_update_notifier',
    'settings'  => 'catchadaptive_theme_options[update_notifier]',
	'type'		=> 'checkbox',
) );
// Update Notifier End